/*
 * cmdtable.c - table of commands
 *
 * Written by
 *  Christian Vogelgsang <chris@vogelgsang.org>
 *
 * This file is part of dtv2ser.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */

#include "cmdtable.h"

#include "command.h"
#include "paramcmd.h"
#include "transfercmd.h"
#include "joycmd.h"
#include "boot.h"

// ---------- The Command Table ---------------------------------------------
command_t command_table[] = {
  // transfer commands
  COMMAND("r","btt",exec_read_memory),
  COMMAND("w","btt",exec_write_memory),
  // transfer status commands
  COMMAND("t",0,exec_transfer_result),

  // main commands
  COMMAND("x",0,exec_reset_dtv),
  COMMAND("g","w",exec_go_memory),
  COMMAND("v",0,exec_version),

#ifdef USE_BOOT
  COMMAND("b","ww",exec_boot_memory),
#endif
  
  // preset commands
  COMMAND("pbs","bb",exec_set_byte_param),
  COMMAND("pbg","b",exec_get_byte_param),
  COMMAND("pws","bw",exec_set_word_param),
  COMMAND("pwg","b",exec_get_word_param),
  COMMAND("ps",0,exec_save_param),
  COMMAND("pl",0,exec_load_param),
  COMMAND("pr",0,exec_reset_param),
  COMMAND("pbd",0,exec_dump_byte_params),
  COMMAND("pwd",0,exec_dump_word_params),
  COMMAND("pd",0,exec_dump_params),
  
  // block commands
#ifdef USE_BLOCKCMD
  COMMAND("dbr","bbww",exec_block_read_memory),
  COMMAND("dbw","bbww",exec_block_write_memory),
#endif

  // diagnose commands
#ifdef USE_DIAGNOSE
  COMMAND("ddr","btt",exec_read_memory_only_dtv),
  COMMAND("ddw","btt",exec_write_memory_only_dtv),
  COMMAND("ddv","btt",exec_verify_memory_only_dtv),
#ifdef USE_BLOCKCMD
  COMMAND("ddbr","bbww",exec_block_read_memory_only_dtv),
  COMMAND("ddbw","bbww",exec_block_write_memory_only_dtv),
#endif
  COMMAND("dsr","btt",exec_read_memory_only_serial),
  COMMAND("dsw","btt",exec_write_memory_only_serial),
  COMMAND("de",0,trigger_error_condition),
#endif

  // joystick commands
#ifdef USE_JOYSTICK
  COMMAND("js",0,exec_joy_stream),
#endif
  
  END_OF_COMMAND
};

